ASTNumberLiteral class

Inheritance

Constructors

ASTNumberLiteral({num? value, Getter<num?>? getter})

Properties

hashCode int
The hash code for this object.
no setterinherited
isFloat bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AstNodeType
no setteroverride
value num?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visit<T>(Visitor<T> visitor) → T
override

Operators

operator ==(Object other) bool
The equality operator.
inherited