ASTStringExpression class

Inheritance

Constructors

ASTStringExpression({required List<ASTNode> parts})

Properties

hashCode int
The hash code for this object.
no setterinherited
parts List<ASTNode>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AstNodeType
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visit<T>(Visitor<T> visitor) → T
override

Operators

operator ==(Object other) bool
The equality operator.
inherited