BasicExprContext class

A basic implementation of ExprContext that can be used as-is or extended.

Inheritance

Constructors

BasicExprContext({String name = '', required Map<String, Object?> variables, ExprContext? enclosing})

Properties

enclosing ExprContext?
The enclosing context, if any. Used for hierarchical variable lookup.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, useful for debugging and logging.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addContextAtTail(ExprContext context) → void
Adds a context to the tail of the current context chain.
inherited
getValue(String key) → ({bool found, Object? value})
Retrieves a value from the context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited