ExprCallableImpl class

Inheritance

Constructors

ExprCallableImpl({required Object? fn(ASTEvaluator evaluator, List<Object> arguments), int arity = 0})

Properties

fn Object? Function(ASTEvaluator evaluator, List<Object> arguments)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

arity() int
override
call(ASTEvaluator evaluator, List<Object> arguments) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited