ExprClass class

Inheritance

Constructors

ExprClass({required String name, required Map<String, Object?> fields, required Map<String, ExprCallable> methods})

Properties

fields Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
methods Map<String, ExprCallable>
final
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

arity() int
override
call(ASTEvaluator evaluator, List<Object> arguments) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited