ExprContext class abstract
An abstract class representing the context for expression evaluation. This context provides access to variables and supports hierarchical scoping.
- Implementers
Constructors
Properties
- enclosing ↔ ExprContext?
-
The enclosing context, if any. Used for hierarchical variable lookup.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of this context, useful for debugging and logging.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addContextAtTail(
ExprContext context) → void - Adds a context to the tail of the current context chain.
-
getValue(
String key) → ({bool found, Object? value}) - Retrieves a value from the context.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited